Skip to contents

CellODE is an R package for single-cell trajectory inference using Variational Autoencoder (VAE) and Neural Ordinary Differential Equations (Neural ODE). The package automatically infers cellular dynamics from single-cell RNA sequencing data, providing:

  • Pseudotime estimation

  • Latent space representation

  • Vector field analysis

  • Trajectory visualization

Details

CellODE is designed for seamless integration with Seurat objects (supporting both V4 and V5). The core model (TNODE) combines a VAE for dimensionality reduction with a Neural ODE for modeling continuous cellular dynamics.

The main workflow involves:

  1. Creating a Trainer object with your Seurat data

  2. Training the model using trainer$train()

  3. Extracting pseudotime using trainer$get_time()

  4. Getting latent representations using trainer$get_latentsp()

  5. Visualizing results with plot_pseudotime() and plot_vector_field()

References

Li, S. et al. (2023). scTour: A deep learning architecture for robust inference and accurate prediction of cellular dynamics. bioRxiv. https://doi.org/10.1101/2023.01.13.523988

Author

Zaoqu Liu liuzaoqu@163.com