Solve ODE forward in time. This is the main integration function that matches scTour's odeint behavior.
Usage
odeint(func, z0, t, method = "euler", options = list())Solve ODE forward in time. This is the main integration function that matches scTour's odeint behavior.
odeint(func, z0, t, method = "euler", options = list())